@@ -9,3 +9,9 @@ DEAD_LETTER_QUEUE_NAME: str = 'dlq'
 TRANSCRIPTION_RESULT_WAITING_EXCHANGE_NAME: str = 'TRANSCRIPTION_RESULT_WAITING'
 
 LIVE_ASR_SERVICE_EVENTS_QUEUE_NAME: str = 'LIVE_ASR_SERVICE_EVENTS'
+
+SPEAKER_DIARIZATION_REQUESTS_QUEUE_NAME: str = 'SPEAKER_DIARIZATION_REQUESTS'
+
+# Delivery modes
+DELIVERY_MODE_TRANSIENT: int = 1
+DELIVERY_MODE_PERSISTENT: int = 2
