@@ -1,6 +1,6 @@
 import dataclasses
 import time
-from threading import RLock, Thread
+from threading import RLock, Thread, Condition
 from typing import Optional, Type, Callable, Any, List, Dict, Tuple, Union
 from inspect import signature
 
@@ -107,6 +107,7 @@ class ConsumerLoop:
         self._prefect_count: int = prefetch_count
         self._global_prefetch: bool = global_prefetch
         self._loop: Thread = Thread(name='consumer-loop', target=ConsumerLoop._consumer_loop, args=[self], daemon=True)
+        self._add_listener_condition: Condition = Condition()
 
         self._open_channel()
         self._loop.start()
@@ -153,8 +154,12 @@ class ConsumerLoop:
 
         while not self._closed:
             try:
-                self._open_channel()
-                self._channel.start_consuming()
+                if self._queues_listener:
+                    self._open_channel()
+                    self._channel.start_consuming()
+                else:
+                    with self._add_listener_condition:
+                        self._add_listener_condition.wait()
             except Exception as e:
                 logger.exception('Consumer loop interrupted: %s', str(e))
 
@@ -247,6 +252,9 @@ class ConsumerLoop:
                 self._channel.basic_consume(queue=queue_name,
                                             on_message_callback=self._dispatch_message,
                                             auto_ack=False)
+
+                with self._add_listener_condition:
+                    self._add_listener_condition.notify_all()
             except (ChannelClosed, ConnectionClosedByBroker) as e:
                 logger.exception(str(e))
                 self._open_channel()
