@@ -40,6 +40,14 @@ class Exchange:
             return NotImplemented
 
 
+@dataclasses.dataclass(frozen=True)
+class Message:
+    queue: str
+    exchange: str
+    body: bytes
+    headers: Dict[str, str]
+
+
 DEFAULT_EXCHANGE: Exchange = Exchange(name=constants.DEFAULT_EXCHANGE_NAME,
                                       type=ExchangeType.direct.value,
                                       durable=True,
